@@ -40,10 +40,19 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'retry_files_enabled', 'False')
     config.set('defaults', 'log_path',
                os.path.join(work_dir, 'ansible.log'))
+    config.set('defaults', 'forks', '25')
+    config.set('defaults', 'timeout', '30')
 
     # mistral user has no home dir set, so no place to save a known hosts file
     config.set('ssh_connection', 'ssh_args',
-               '-o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no')
+               '-o UserKnownHostsFile=/dev/null '
+               '-o StrictHostKeyChecking=no '
+               '-o ControlMaster=auto '
+               '-o ControlPersist=30m')
+    config.set('ssh_connection', 'control_path_dir',
+               os.path.join(work_dir, 'ansible-ssh'))
+    config.set('ssh_connection', 'retries', '8')
+    config.set('ssh_connection', 'pipelining', 'True')
 
     with open(ansible_config_path, 'w') as configfile:
         config.write(configfile)
@@ -365,13 +374,14 @@ class AnsiblePlaybookAction(base.TripleOAction):
     def post_message(self, queue, message):
         """Posts message to queue
 
-        Breaks the message up it up by maximum message size if needed.
+        Breaks the message up by maximum message size if needed.
         """
 
         start = 0
-        # We use 90% of the max message size to account for any overhead,
-        # plus the wrapped dict structure from format_message
-        message_size = int(self.max_message_size * 0.9)
+        # We use 50% of the max message size to account for any overhead
+        # due to JSON encoding plus the wrapped dict structure from
+        # format_message.
+        message_size = int(self.max_message_size * 0.5)
         while True:
             end = start + message_size
             message_part = message[start:end]
