@@ -50,7 +50,7 @@ class Config(object):
                 for idx, name in enumerate(shortnames):
                     if 'server_ids' in role_node_id_map:
                         server_id = role_node_id_map['server_ids'][role][idx]
-                        servers[server_id] = name
+                        servers[server_id] = name.lower()
         return servers
 
     def get_deployment_data(self, stack,
@@ -297,6 +297,8 @@ class Config(object):
 
         group_vars_dir = os.path.join(tmp_path, 'group_vars')
         self._mkdir(group_vars_dir)
+        host_vars_dir = os.path.join(tmp_path, 'host_vars')
+        self._mkdir(host_vars_dir)
 
         for server, deployments in server_deployments.items():
             deployment_template = env.get_template('deployment.j2')
